@@ -29,6 +29,13 @@
 #'
 #' iris %>% summarise_vars(is.numeric,min,by ="Species")
 #' mtcars %>% summarise_vars(is.numeric,mean,by = "vs,am")
+#'
+#' # use multiple functions on multiple columns
+#' iris %>%
+#'   summarise_vars(is.numeric,.func = list(mean,sd,median))
+#' iris %>%
+#'   summarise_vars(is.numeric,.func = list(mean,sd,median),by = Species)
+#'
 
 globalVariables("res")
 
@@ -74,11 +81,39 @@ summarise_vars = function (.data, .cols = NULL, .func, ...,by) {
           str_glue("select_dt(dt[0],{.cols}) %>% names() -> sel_name")))
   }
 
-  eval(parse(text = str_glue(
-  "res = dt[,lapply(.SD, .func, ...), by = {.by},.SDcols = sel_name]")))
-  res[, unique(names(res)), with = FALSE]
+  if(!is.list(.func)){
+    eval(parse(text = str_glue(
+      "res = dt[,lapply(.SD, .func, ...), by = {.by},.SDcols = sel_name]")))
+    res[, unique(names(res)), with = FALSE]
+  }else{
+    func_names = sapply(substitute(.func),deparse) %>% .[-1]
+    lapply(func_names,function(func){
+      eval(parse(text = str_glue(
+        "res = dt[,lapply(.SD, get(func), ...),
+        by = {.by},.SDcols = sel_name][,fun_name:=func]")))
+    }) %>% rbindlist()
+  }
+
 }
 
+# summarise_vars = function (.data, .cols = NULL, .func, ...,by) {
+#   dt = as_dt(.data)
+#   deparse(substitute(.cols)) -> .cols
+#   deparse(substitute(by)) -> .by
+#   if (.cols == "NULL")
+#     sel_name = names(dt[0])
+#   else{
+#     eval(
+#       parse(
+#         text =
+#           str_glue("select_dt(dt[0],{.cols}) %>% names() -> sel_name")))
+#   }
+#
+#   eval(parse(text = str_glue(
+#   "res = dt[,lapply(.SD, .func, ...), by = {.by},.SDcols = sel_name]")))
+#   res[, unique(names(res)), with = FALSE]
+# }
+
 
 
 #' @rdname summarise_dt
